<?php

namespace app\admin\controller;

use app\admin\logic\RoleLogic;
use app\BaseController;
use think\exception\ValidateException;
use think\facade\Config;
use think\facade\Validate;

//角色
class Role extends BaseController
{
    //获取角色列表
    public function list()
    {
        $param = $this->request->only([
            'page'=>1,
            'size'=>10,
            'name'=>'',
            'level'=>'',
            'status'=>''
        ],'post');

        $val= Validate::rule(array_merge(Config::get('validate_rules.common'),Config::get('validate_rules.roleList')));

        if(!$val->check($param)) throw new ValidateException($val->getError());

        return RoleLogic::list($param);
    }

    //获取全部角色
    public function all()
    {
        $keyword = $this->request->post('keyword', '');

        return RoleLogic::all($keyword);
    }

    //添加角色
    public function add()
    {
        $param = $this->request->only(['name','level','remark','action_data'],'post');

        $val= Validate::rule(Config::get('validate_rules.RoleAdd'));

        if(!$val->check($param)) throw new ValidateException($val->getError());

        return RoleLogic::add($param);
    }

    //获取角色详情
    public function read()
    {
        $id=$this->request->post('id/d',0);
        return RoleLogic::read($id);
    }

    //编辑角色
    public function edit()
    {
        $param = $this->request->only(['id','name','level','remark','action_data'],'post');

        $val= Validate::rule(array_merge(Config::get('validate_rules.RoleAdd'),['id'=>'require|number|gt:0']));

        if(!$val->check($param)) throw new ValidateException($val->getError());

        return RoleLogic::edit($param);

    }

    //删除角色
    public function delete()
    {
        $id = $this->request->post('id/d', 0);

        return RoleLogic::delete($id);
    }

    //启禁用角色
    public function status()
    {
        $param = $this->request->only(['id', 'status'], 'post');

        $val = Validate::rule(Config::get('validate_rules.status'));

        if (!$val->check($param)) throw new ValidateException($val->getError());

        return RoleLogic::status($param);
    }

}