<?php

namespace app\admin\logic;

use app\model\CommonModel;
use app\model\GoodModel;
use app\model\OrderModel;
use think\Exception;
use think\facade\Db;
use think\facade\Validate;
use think\response\Json;

class OrderLogic extends BaseLogic
{
    //列表
    public static function list(array $data = []): Json
    {

        $db = OrderModel::alias('a')
            ->leftJoin('company b', 'b.id=a.company_id AND b.is_del=' . CommonModel::$del_normal)
            ->leftJoin('card c', 'c.id=a.card_id AND c.is_del=' . CommonModel::$del_normal)
            ->leftJoin('account d', 'd.id=a.uid AND d.is_del=' . CommonModel::$del_normal)
            ->leftJoin('addr e', 'e.id=a.addr_id AND e.is_del=' . CommonModel::$del_normal)
            ->leftJoin('good f', 'f.id=a.good_id AND f.is_del=' . CommonModel::$del_normal)
            ->where('a.is_del', CommonModel::$del_normal);

        if ($data['orderCode'] != '') $db->whereLike('a.orderCode', '%' . $data['orderCode'] . '%');
        if ($data['status'] != '') $db->where('a.status', $data['status']);
        if ($data['name'] !== '') $db->whereLike('d.name', '%' . $data['name'] . '%');
        if ($data['username']) $db->whereLike('d.username', '%' . $data['username'] . '%');
        if (($data['start_date'] != '') && ($data['end_date'] != '')) $db->whereBetween('a.addtime', [$data['start_date'], $data['end_date']]);
        if ($data['type'] !== '') $db->where('a.type', $data['type']);

        $count = $db->count('a.id');

        $list = $db
            ->field('a.id,a.orderCode,a.type,b.title company_title,c.title card_title,d.name,d.username,a.num,e.contactor,e.mobile,a.status,a.post_name,a.post_code,a.addtime,e.addr_code,"" addr_name,e.addr,f.good_code,f.good_name,f.good_cover_img')
            ->page($data['page'], $data['size'])
            ->withAttr('addr_code', function ($val) {
                return explode(',', $val);
            })
            ->withAttr('addr_name', function ($val, $da) {
                return $da['addr_code'] ? get_addr_name($da['addr_code']) : '';
            })
            ->order('a.addtime desc')
            ->select()
            ->toArray();

        return json_show(CommonModel::$success, '获取订单列表成功', ['count' => $count, 'list' => $list]);
    }

    //详情
    public static function read(int $id = 0): Json
    {
        $rs = $db = OrderModel::alias('a')
            ->field('a.id,a.orderCode,a.type,b.title company_title,c.title card_title,d.name,d.username,a.num,e.contactor,e.mobile,e.addr_code,a.status,a.post_name,a.post_code,a.addtime,"" addr_name,f.good_code,f.good_name,f.good_cover_img')
            ->leftJoin('company b', 'b.id=a.company_id AND b.is_del=' . CommonModel::$del_normal)
            ->leftJoin('card c', 'c.id=a.card_id AND c.is_del=' . CommonModel::$del_normal)
            ->leftJoin('account d', 'd.id=a.uid AND d.is_del=' . CommonModel::$del_normal)
            ->leftJoin('addr e', 'e.id=a.addr_id AND e.is_del=' . CommonModel::$del_normal)
            ->leftJoin('good f', 'f.id=a.good_id AND f.is_del=' . CommonModel::$del_normal)
            ->where(['a.is_del' => CommonModel::$del_normal, 'a.id' => $id])
            ->withAttr('addr_code', function ($val) {
                return explode(',', $val);
            })
            ->withAttr('addr_name', function ($val, $da) {
                return $da['addr_code'] ? get_addr_name($da['addr_code']) : '';
            })
            ->findOrEmpty()
            ->toArray();
        return json_show(CommonModel::$success, '获取商品详情成功', $rs);
    }

    //导出
    public static function export(array $data = []): Json
    {

        $db = OrderModel::alias('a')
            ->leftJoin('company b', 'b.id=a.company_id AND b.is_del=' . CommonModel::$del_normal)
            ->leftJoin('card c', 'c.id=a.card_id AND c.is_del=' . CommonModel::$del_normal)
            ->leftJoin('account d', 'd.id=a.uid AND d.is_del=' . CommonModel::$del_normal)
            ->leftJoin('addr e', 'e.id=a.addr_id AND e.is_del=' . CommonModel::$del_normal)
            ->leftJoin('good f', 'f.id=a.good_id AND f.is_del=' . CommonModel::$del_normal)->where('a.is_del', CommonModel::$del_normal)
            ->where('a.is_del', CommonModel::$del_normal);

        if ($data['orderCode'] != '') $db->whereLike('a.orderCode', '%' . $data['orderCode'] . '%');
        if ($data['status'] != '') $db->where('a.status', $data['status']);
        if ($data['name'] !== '') $db->whereLike('d.name', '%' . $data['name'] . '%');
        if ($data['username']) $db->whereLike('d.username', '%' . $data['username'] . '%');
        if (($data['start_date'] != '') && ($data['end_date'] != '')) $db->whereBetween('a.addtime', [$data['start_date'], $data['end_date']]);
        if ($data['type'] != '') $db->where('a.type', $data['type']);

        $status = [CommonModel::$status_not_deliver => '待发货', CommonModel::$status_deliver => '已发货', CommonModel::$status_receipt => '已收货'];
        $type = [GoodModel::$type_shopping => '商城', GoodModel::$type_exchange => '兑换'];
        $list = $db
            ->field('a.id 订单ID,a.orderCode 订单编号,a.type,b.title 业务公司,c.title 卡类型,d.name 购买用户名,d.username 购买账号,a.num 购买数量,e.contactor 收货联系人,e.mobile 收货联系电话,e.addr_code,a.status 状态,a.post_name 物流公司,a.post_code 物流单号,a.addtime 创建时间,e.addr,f.good_code 商品编码,f.good_name 商品名称')
            ->order('a.addtime desc')
            ->cursor();

        $da = [];
        foreach ($list as $v) {
            $v = $v->toArray();
            $v['收货地址'] = $v['addr_code'] ? get_addr_name($v['addr_code']) . $v['addr'] : $v['addr'];
            $v['状态'] = $status[$v['状态']] ?? '';
            $v['订单类型'] = $type[$v['type']] ?? '';

            unset($v['addr_code']);
            unset($v['addr']);
            unset($v['type']);

            $da[] = $v;
        }

        if (empty($da)) $da[] = '没有可供导出的数据';

        $headerArr = array_keys($da[0]);
        excel_save('订单导出' . date('YmdHis'), $headerArr, $da);

    }

    //发货
    public static function deliver(array $list = [])
    {

        $db = new OrderModel();
        $temp = $db
            ->field('id,orderCode')
            ->where(['is_del' => CommonModel::$del_normal])
            ->where('status', '<>', CommonModel::$status_not_deliver)
            ->whereIn('orderCode', array_column($list, 'orderCode'))
            ->findOrEmpty();

        if (!$temp->isEmpty()) return json_show(CommonModel::$error_param, $temp->orderCode . '订单并不是未发货状态');

        $val = Validate::rule([
            'orderCode|订单编号' => 'require|length:18',
            'post_name|物流公司' => 'require|max:255',
            'post_code|物流单号' => 'require|max:255',
        ]);

        Db::startTrans();
        try {

            $date = date('Y-m-d H:i:s');

            foreach ($list as $order) {

                if (!$val->check($order)) throw new Exception($val->getError());

                $db->where([
                    'is_del' => CommonModel::$del_normal,
                    'orderCode' => $order['orderCode'],
                    'status' => CommonModel::$status_not_deliver,
                ])->save([
                    'status' => CommonModel::$status_deliver,
                    'post_name' => $order['post_name'],
                    'post_code' => $order['post_code'],
                    'updater' => self::$uname,
                    'updaterid' => self::$uid,
                    'updatetime' => $date,
                ]);
            }

            Db::commit();
            return json_show(CommonModel::$success, '发货成功');
        } catch (Exception $exception) {
            Db::rollback();
            return json_show(CommonModel::$error_param, '发货失败,' . $exception->getMessage());
        }

    }

}